#Author: Linus Svenberg

#The following packages are needed for the script to run

library(ggplot2)
library(tidyverse)
library(ggpubr)
library(VennDiagram)
library(ggfortify)
library(multcompView)
#setwd("~/
#remove the hashtag and specify the location of datafiles in the setwd-commando so that the code may run
#-----------------------------------------------------------Loading in the raw data------------------------------------------------------
dataset = read_delim("Figure_data_1.csv",
                     delim=",",
                     col_names=TRUE,
                     trim_ws=TRUE)


#-----------------------------------------------------------Creating plant specific data frames-------------------------------------------#
#these plant specific dataframes will be used later for visualization, but we can also use them for creating our plot specific dataframes
#thus we divide the large dataset now, as to enable the construction of the other, plot specific dataframes.
dataset_ber = dataset %>%
  select(Compound, RT, RI, Class, `Ber_root_1-1`,`Ber_root_1-2`,`Ber_root_2-1`,`Ber_root_2-2`,`Ber_shoot_1-1`,`Ber_shoot_1-2`,
         `Ber_shoot_2-1`, `Ber_shoot_2-2`)

dataset_pap = dataset %>%
  select(Compound, RT, RI, Class, `Pap_root_1-1`,`Pap_root_1-2`,`Pap_root_2-1`,`Pap_root_2-2`,`Pap_shoot_1-1`,`Pap_shoot_1-2`,
         `Pap_shoot_2-1`, `Pap_shoot_2-2`) 

dataset_tor = dataset %>%
  select(Compound, RT, RI, Class, `Tor_root_1-1`,`Tor_root_1-2`,`Tor_root_2-1`,`Tor_root_2-2`,`Tor_shoot_1-1`,`Tor_shoot_1-2`,
         `Tor_shoot_2-1`, `Tor_shoot_2-2`)


#----------------------------------------Pie chart for dispersion of compounds across all samples------------------------------------------
#We also want a piechart of the total dispersion of compounds in the classes for the 45 detected compounds. So we construct the following
#small matrix by creating 4 entries, which puts the number of compounds in each class as a percentage

TR = str_count(dataset$Class, "TR")
TR = sum(TR)
AL = str_count(dataset$Class, "AL")
AL = sum(AL)
BP = str_count(dataset$Class, "BP")
BP = sum(BP)
C5 = str_count(dataset$Class, "C5")
C5 = sum(C5)
NS = str_count(dataset$Class, "NS")
NS = sum(NS)
Cyc = str_count(dataset$Class, "Cyc")
Cyc = sum(Cyc)

pie_total = data.frame(Class=c("TR","AL","BP","C5","NS","Cyc"),Count=c(TR,AL,BP,C5,NS,Cyc))

pie_total= pie_total %>%
  arrange(desc(Class))
pie_total= pie_total %>%
  mutate(prop = pie_total$Count / sum(pie_total$Count) *100)
pie_total= pie_total %>%
  mutate_if(is.numeric, round,digits=2)
pie_total= pie_total %>%
  mutate(ypos = cumsum(prop)- 0.5*prop)

#------------------------------------------------------Venn diagram-------------------------------------------------------------------------

ber_mean = data.frame(rowMeans(dataset_ber[,5:12]))
pap_mean = data.frame(rowMeans(dataset_pap[,5:12]))
tor_mean = data.frame(rowMeans(dataset_tor[,5:12]))

ber_venn = ber_mean%>%
  mutate(Compound = dataset$Compound)

pap_venn = pap_mean%>%
  mutate(Compound = dataset$Compound)

tor_venn = tor_mean%>%
  mutate(Compound = dataset$Compound)
#removing all zeros in the dataset
ber_venn = filter(ber_venn, ber_venn$rowMeans.dataset_ber...5.12..>0)
pap_venn = filter(pap_venn, pap_venn$rowMeans.dataset_pap...5.12..>0)
tor_venn = filter(tor_venn, tor_venn$rowMeans.dataset_tor...5.12..>0)
#So now we merge all the list with the compounds into one matrix

set1 = ber_venn$Compound
set2 = pap_venn$Compound
set3 = tor_venn$Compound
x=list(set1,set2,set3)

venn_plot <-venn.diagram(x,
                         category.names = c("C. dactylon", "C.exaltatus", "P.repens"),lwd = c(0.7, 0.7, 0.7), lty = c(0.7, 0.7, 0.7),
                         cat.fontface="italic",
                         col = c("black","black","black"),
                         fill = c("grey", "grey", "grey"), alpha = c(0.6, 0.6, 0.6), filename = NULL,cat.cex = 0.7,
                         main= "Venn diagram of distribution of compounds",
                         main.cex = 0.8)

#---------------------------------------------------------------------Barplot-----------------------------------------------------------


dataset_bar = read_delim("Figure_data_2.csv",
                         delim=";", 
                         locale= locale(decimal_mark = ","),
                         col_names=TRUE,
                         trim_ws=TRUE)

bar_comp=ggplot(dataset_bar, aes(x=Plant, y=Amount, fill=Origin))+
  geom_bar(stat="identity", position=position_dodge())+
  geom_text(aes(label=Amount), vjust=-0.5, color="black",
            position = position_dodge(0.9), size=3.5)+
  scale_fill_grey()+
  theme_bw()+
  ylim(0,26)+
  labs(title = "Distribution of compounds and number of compounds detected in each plant part", y="Number of compounds")+
  theme(legend.position = c(0.1,0.7),
        legend.text = element_text(size=8),
        legend.title = element_text(size=8),
        plot.title = element_text(size=10),
        axis.title.y = element_text(size=8),
        axis.text.x = element_text(face="italic"))+
  scale_x_discrete(labels=c("A" = "C. dactylon", "B" = "P. repens",
                            "C" = "C. exaltatus"))

bar_comp


horz_bar_comp= ggplot(pie_total, aes(x = Class, y = prop))+
  geom_col(width = 0.7)+
  scale_fill_grey()+
  theme_bw()+
  ylim(0,75)+
  geom_text(aes(label=prop), vjust=0.4, hjust=-0.25,color="black",
            position = position_dodge(0.5), size=3)+
  labs(title="Distribution of compound classes for \nall samples as percentages",y="Percentage [%]")+
  theme(plot.title = element_text(size=10))

horz_bar_comp = horz_bar_comp + coord_flip()

pie_tot_and_venn=ggarrange(horz_bar_comp, venn_plot, labels = c("B","C"))
pie_tot_and_venn
ggarrange(bar_comp,pie_tot_and_venn, ncol=1, nrow=2, labels = c("A"))


#---------------------------------------------------------Seperate pie charts for sample type---------------------------------------------


dataset_bar_sep = read_delim("Figure_data_3.csv",
                             delim=";", 
                             locale= locale(decimal_mark = ","),
                             col_names=TRUE,
                             trim_ws=TRUE)

dataset_bar_sep_roots = dataset_bar_sep[c(1:6,13:18,25:30),]
dataset_bar_sep_shoots = dataset_bar_sep[c(7:12,19:24,31:36),]
labels_bar_sep=c("C. dactylon","P.repens","C. exaltatus")
bar_roots_sep=ggplot(dataset_bar_sep_roots, aes(x=Plant, y=Amount, fill=Class))+
  geom_bar(stat="identity", position=position_dodge())+
  geom_text(aes(label=Amount), vjust=-0.5, color="black",
            position = position_dodge(0.9), size=3.5)+
  geom_text(aes(label=Class), vjust=-2.5, color="black",
            position = position_dodge(0.9), size=3)+
  scale_fill_grey()+
  theme_bw()+
  labs(title = "Distribution of compounds in different classes for root samples", y="Number of compounds")+
  theme(legend.position = "none",
        legend.text = element_text(size=8),
        legend.title = element_text(size=8),
        plot.title = element_text(size=10),
        axis.title.y = element_text(size=8),
        axis.text.x = element_text(face="italic"))+
  scale_x_discrete(labels=labels_bar_sep)+
  scale_y_continuous(breaks=seq(0, 15, 3), limits=c(0, 15))


bar_shoots_sep=ggplot(dataset_bar_sep_shoots, aes(x=Plant, y=Amount, fill=Class))+
  geom_bar(stat="identity", position=position_dodge())+
  geom_text(aes(label=Amount), vjust=-0.5, color="black",
            position = position_dodge(0.9), size=3.5)+
  geom_text(aes(label=Class), vjust=-2.5, color="black",
            position = position_dodge(0.9), size=3)+
  scale_fill_grey()+
  theme_bw()+
  labs(title = "Distribution of compounds in different classes for shoot samples", y="Number of compounds")+
  theme(legend.position = "none",
        legend.text = element_text(size=8),
        legend.title = element_text(size=8),
        plot.title = element_text(size=10),
        axis.title.y = element_text(size=8),
        axis.text.x = element_text(face="italic"))+
  scale_x_discrete(labels=labels_bar_sep)+
  scale_y_continuous(breaks=seq(0, 25, 5), limits=c(0, 25))
ggarrange(bar_roots_sep, bar_shoots_sep, ncol=1, nrow=2, labels=c("A","B"))


